API Reference
=============

.. automodule:: materforge
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

Core Module
-----------

.. automodule:: materforge.core
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

Material Class
~~~~~~~~~~~~~~

.. autoclass:: materforge.Material
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

Algorithms Module
-----------------

.. automodule:: materforge.algorithms
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

Parsing Module
--------------

.. automodule:: materforge.parsing
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

Visualization Module
--------------------

.. automodule:: materforge.visualization
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:
